#!/bin/sh
# Copyright (C) 2002, 2005  Slackware Linux, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Swap glibc on the fly.
#
# If we're on a running system we have to handle this _very_ carefully.  :-)
# The tricks involved here get trickier every time...

# Modified by Damian Rakowski for KateOS

if [ -x /sbin/ldconfig -a -d /lib/incoming ]; then # swap on the fly
  # First create copies of the incoming libraries:
  ( cd lib/incoming
    for file in * ; do
      if [ ! -r ../${file}.incoming ]; then
        cp -a $file ../${file}.incoming
      fi
    done
  )
  # Then switch to them all at once:
  /sbin/ldconfig -l /lib/*.incoming 2> /dev/null
  # Finally, rename them and clean up:
  ( cd lib
    for file in *.incoming ; do
      rm -f `basename $file .incoming`
      cp -a $file `basename $file .incoming`
      /sbin/ldconfig -l `basename $file .incoming`
      rm -f $file
    done
  )
else # no ldconfig?  Good, it's safe to just jam it on home (and make links below):
  ( cd lib/incoming
    for file in * ; do
      cp -a $file ..
    done
  )
fi
# Now, get rid of the temporary directory:
rm -rf lib/incoming

if [ ! -x /sbin/ldconfig ]; then
( cd lib/ ; rm -rf libnss_nis.so.2 )
( cd lib/ ; ln -sf libnss_nis-2.5.so libnss_nis.so.2 )
( cd lib/ ; rm -rf libm.so.6 )
( cd lib/ ; ln -sf libm-2.5.so libm.so.6 )
( cd lib/ ; rm -rf libnss_files.so.2 )
( cd lib/ ; ln -sf libnss_files-2.5.so libnss_files.so.2 )
( cd lib/ ; rm -rf libresolv.so.2 )
( cd lib/ ; ln -sf libresolv-2.5.so libresolv.so.2 )
( cd lib/ ; rm -rf libnsl.so.1 )
( cd lib/ ; ln -sf libnsl-2.5.so libnsl.so.1 )
( cd lib/ ; rm -rf libutil.so.1 )
( cd lib/ ; ln -sf libutil-2.5.so libutil.so.1 )
( cd lib/ ; rm -rf libnss_compat.so.2 )
( cd lib/ ; ln -sf libnss_compat-2.5.so libnss_compat.so.2 )
( cd lib/ ; rm -rf libthread_db.so.1 )
( cd lib/ ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd lib/ ; rm -rf libnss_hesiod.so.2 )
( cd lib/ ; ln -sf libnss_hesiod-2.5.so libnss_hesiod.so.2 )
( cd lib/ ; rm -rf libanl.so.1 )
( cd lib/ ; ln -sf libanl-2.5.so libanl.so.1 )
( cd lib/ ; rm -rf libcrypt.so.1 )
( cd lib/ ; ln -sf libcrypt-2.5.so libcrypt.so.1 )
( cd lib/ ; rm -rf libBrokenLocale.so.1 )
( cd lib/ ; ln -sf libBrokenLocale-2.5.so libBrokenLocale.so.1 )
( cd lib/ ; rm -rf ld-linux.so.2 )
( cd lib/ ; ln -sf ld-2.5.so ld-linux.so.2 )
( cd lib/ ; rm -rf libdl.so.2 )
( cd lib/ ; ln -sf libdl-2.5.so libdl.so.2 )
( cd lib/ ; rm -rf libnss_dns.so.2 )
( cd lib/ ; ln -sf libnss_dns-2.5.so libnss_dns.so.2 )
( cd lib/ ; rm -rf libpthread.so.0 )
( cd lib/ ; ln -sf libpthread-2.5.so libpthread.so.0 )
( cd lib/ ; rm -rf libnss_nisplus.so.2 )
( cd lib/ ; ln -sf libnss_nisplus-2.5.so libnss_nisplus.so.2 )
( cd lib/ ; rm -rf libc.so.6 )
( cd lib/ ; ln -sf libc-2.5.so libc.so.6 )
( cd lib/ ; rm -rf librt.so.1 )
( cd lib/ ; ln -sf librt-2.5.so librt.so.1 )
( cd lib/ ; rm -rf librt.so )
( cd lib/ ; ln -sf librt-2.5.so librt.so )

fi

( cd usr/lib ; rm -rf libnss_nisplus.so )
( cd usr/lib ; ln -sf ../../lib/libnss_nisplus.so.2 libnss_nisplus.so )
( cd usr/lib ; rm -rf libresolv.so )
( cd usr/lib ; ln -sf ../../lib/libresolv.so.2 libresolv.so )
( cd usr/lib ; rm -rf libnsl.so )
( cd usr/lib ; ln -sf ../../lib/libnsl.so.1 libnsl.so )
( cd usr/lib ; rm -rf libnss_hesiod.so )
( cd usr/lib ; ln -sf ../../lib/libnss_hesiod.so.2 libnss_hesiod.so )
( cd usr/lib ; rm -rf libnss_files.so )
( cd usr/lib ; ln -sf ../../lib/libnss_files.so.2 libnss_files.so )
( cd usr/lib ; rm -rf libm.so )
( cd usr/lib ; ln -sf ../../lib/libm.so.6 libm.so )
( cd usr/lib ; rm -rf libutil.so )
( cd usr/lib ; ln -sf ../../lib/libutil.so.1 libutil.so )
( cd usr/lib ; rm -rf libnss_compat.so )
( cd usr/lib ; ln -sf ../../lib/libnss_compat.so.2 libnss_compat.so )
( cd usr/lib ; rm -rf libthread_db.so )
( cd usr/lib ; ln -sf ../../lib/libthread_db.so.1 libthread_db.so )
( cd usr/lib ; rm -rf libcrypt.so )
( cd usr/lib ; ln -sf ../../lib/libcrypt.so.1 libcrypt.so )
( cd usr/lib ; rm -rf libBrokenLocale.so )
( cd usr/lib ; ln -sf ../../lib/libBrokenLocale.so.1 libBrokenLocale.so )
( cd usr/lib ; rm -rf libdl.so )
( cd usr/lib ; ln -sf ../../lib/libdl.so.2 libdl.so )
( cd usr/lib ; rm -rf libnss_dns.so )
( cd usr/lib ; ln -sf ../../lib/libnss_dns.so.2 libnss_dns.so )
( cd usr/lib ; rm -rf librt.so )
( cd usr/lib ; ln -sf ../../lib/librt.so.1 librt.so )
( cd usr/lib ; rm -rf libanl.so )
( cd usr/lib ; ln -sf ../../lib/libanl.so.1 libanl.so )
( cd usr/lib ; rm -rf libnss_nis.so )
( cd usr/lib ; ln -sf ../../lib/libnss_nis.so.2 libnss_nis.so )
( cd sbin ; rm -rf sln )
( cd sbin ; ln -sf /bin/sln sln )
